@@ -10,12 +10,12 @@
 #define DOLPHIN_MAINWINDOW_H
 
 #include "dolphintabwidget.h"
-#include <config-baloo.h>
+#include "config-dolphin.h"
 #include <KFileItemActions>
 #include <kio/fileundomanager.h>
 #include <kxmlguiwindow.h>
 
-#ifdef HAVE_BALOO
+#if HAVE_BALOO
     #include "panels/information/informationpanel.h"
 #endif
 
@@ -138,6 +138,8 @@ public Q_SLOTS:
      */
     void activateWindow();
 
+    bool isActiveWindow();
+
     /**
      * Determines if a URL is open in any tab.
      * @note Use of QString instead of QUrl is required to be callable via DBus.
@@ -147,6 +149,15 @@ public Q_SLOTS:
      */
     bool isUrlOpen(const QString &url);
 
+    /**
+     * Determines if a URL or it's parent is open in any tab.
+     * @note Use of QString instead of QUrl is required to be callable via DBus.
+     *
+     * @param url URL to look for
+     * @returns true if url or it's parent is currently open in a tab, false otherwise.
+     */
+    bool isUrlOrParentOpen(const QString &url);
+
 
     /**
      * Pastes the clipboard data into the currently selected folder
@@ -399,6 +410,12 @@ private Q_SLOTS:
     /** Opens a terminal window for the current location. */
     void openTerminal();
 
+    /** Opens terminal windows for the selected items' locations. */
+    void openTerminalHere();
+
+    /** Opens a terminal window for the URL. */
+    void openTerminalJob(const QUrl& url);
+
     /** Focus a Terminal Panel. */
     void focusTerminalPanel();
 
@@ -475,14 +492,11 @@ private Q_SLOTS:
      * @pos           Position in screen coordinates.
      * @item          File item context. If item is null, the context menu
      *                should be applied to \a url.
+     * @selectedItems The selected items for which the context menu
+     *                is opened. This list generally includes \a item.
      * @url           URL which contains \a item.
-     * @customActions Actions that should be added to the context menu,
-     *                if the file item is null.
      */
-    void openContextMenu(const QPoint& pos,
-                         const KFileItem& item,
-                         const QUrl& url,
-                         const QList<QAction*>& customActions);
+    void openContextMenu(const QPoint& pos, const KFileItem& item, const KFileItemList &selectedItems, const QUrl& url);
 
     /**
      * Updates the menu that is by default at the right end of the toolbar.
@@ -653,6 +667,9 @@ private:
      */
     bool addHamburgerMenuToToolbar();
 
+    /** Creates an action representing an item in the URL navigator history */
+    static QAction *urlNavigatorHistoryAction(const KUrlNavigator *urlNavigator, int historyIndex, QObject *parent = nullptr);
+
 private:
     /**
      * Implements a custom error handling for the undo manager. This
@@ -693,6 +710,7 @@ private:
     QMenu m_searchTools;
     KFileItemActions m_fileItemActions;
 
+    friend class DolphinMainWindowTest;
 };
 
 inline DolphinViewContainer* DolphinMainWindow::activeViewContainer() const
