@@ -13,6 +13,7 @@
 
 #include <KIO/PreviewJob>
 #include <KLocalizedString>
+#include <KPluginMetaData>
 #include <KServiceTypeTrader>
 
 #include <QHBoxLayout>
@@ -45,9 +46,12 @@ PreviewsSettingsPage::PreviewsSettingsPage(QWidget* parent) :
     m_listView = new QListView(this);
     QScroller::grabGesture(m_listView->viewport(), QScroller::TouchGesture);
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 87)
     ServiceItemDelegate* delegate = new ServiceItemDelegate(m_listView, m_listView);
     connect(delegate, &ServiceItemDelegate::requestServiceConfiguration,
             this, &PreviewsSettingsPage::configureService);
+    m_listView->setItemDelegate(delegate);
+#endif
 
     ServiceModel* serviceModel = new ServiceModel(this);
     QSortFilterProxyModel* proxyModel = new QSortFilterProxyModel(this);
@@ -56,7 +60,6 @@ PreviewsSettingsPage::PreviewsSettingsPage(QWidget* parent) :
     proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
 
     m_listView->setModel(proxyModel);
-    m_listView->setItemDelegate(delegate);
     m_listView->setVerticalScrollMode(QListView::ScrollPerPixel);
     m_listView->setUniformItemSizes(true);
 
@@ -94,8 +97,8 @@ PreviewsSettingsPage::PreviewsSettingsPage(QWidget* parent) :
     loadSettings();
 
     connect(m_listView, &QListView::clicked, this, &PreviewsSettingsPage::changed);
-    connect(m_localFileSizeBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &PreviewsSettingsPage::changed);
-    connect(m_remoteFileSizeBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &PreviewsSettingsPage::changed);
+    connect(m_localFileSizeBox, &QSpinBox::valueChanged, this, &PreviewsSettingsPage::changed);
+    connect(m_remoteFileSizeBox, &QSpinBox::valueChanged, this, &PreviewsSettingsPage::changed);
 }
 
 PreviewsSettingsPage::~PreviewsSettingsPage()
@@ -153,6 +156,7 @@ void PreviewsSettingsPage::showEvent(QShowEvent* event)
     SettingsPageBase::showEvent(event);
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 87)
 void PreviewsSettingsPage::configureService(const QModelIndex& index)
 {
     const QAbstractItemModel* model = index.model();
@@ -163,22 +167,26 @@ void PreviewsSettingsPage::configureService(const QModelIndex& index)
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
 }
+#endif
 
 void PreviewsSettingsPage::loadPreviewPlugins()
 {
     QAbstractItemModel* model = m_listView->model();
 
-    const KService::List plugins = KServiceTypeTrader::self()->query(QStringLiteral("ThumbCreator"));
-    for (const KService::Ptr& service : plugins) {
-        const bool configurable = service->property(QStringLiteral("Configurable"), QVariant::Bool).toBool();
-        const bool show = m_enabledPreviewPlugins.contains(service->desktopEntryName());
+    const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
+    for (const KPluginMetaData &plugin : plugins) {
+        const bool show = m_enabledPreviewPlugins.contains(plugin.pluginId());
 
         model->insertRow(0);
         const QModelIndex index = model->index(0, 0);
         model->setData(index, show, Qt::CheckStateRole);
+        model->setData(index, plugin.name(), Qt::DisplayRole);
+        model->setData(index, plugin.pluginId(), ServiceModel::DesktopEntryNameRole);
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 87)
+        const bool configurable = plugin.value(QStringLiteral("Configurable"), false);
         model->setData(index, configurable, ServiceModel::ConfigurableRole);
-        model->setData(index, service->name(), Qt::DisplayRole);
-        model->setData(index, service->desktopEntryName(), ServiceModel::DesktopEntryNameRole);
+#endif
     }
 
     model->sort(Qt::DisplayRole);
