@@ -14,7 +14,7 @@
 
 #include <KFileItem>
 #include <KIO/Job>
-#include <config-baloo.h>
+#include "config-dolphin.h"
 #include <kio/fileundomanager.h>
 #include <kparts/part.h>
 
@@ -35,6 +35,7 @@ class VersionControlObserver;
 class ViewProperties;
 class QLabel;
 class QGraphicsSceneDragDropEvent;
+class QHelpEvent;
 class QRegularExpression;
 
 /**
@@ -510,13 +511,12 @@ Q_SIGNALS:
     /**
      * Is emitted if a context menu is requested for the item \a item,
      * which is part of \a url. If the item is null, the context menu
-     * for the URL should be shown and the custom actions \a customActions
-     * will be added.
+     * for the URL should be shown.
      */
     void requestContextMenu(const QPoint& pos,
                             const KFileItem& item,
-                            const QUrl& url,
-                            const QList<QAction*>& customActions);
+                            const KFileItemList &selectedItems,
+                            const QUrl& url);
 
     /**
      * Is emitted if an information message with the content \a msg
@@ -635,7 +635,7 @@ private Q_SLOTS:
     void slotViewContextMenuRequested(const QPointF& pos);
     void slotHeaderContextMenuRequested(const QPointF& pos);
     void slotHeaderColumnWidthChangeFinished(const QByteArray& role, qreal current);
-    void slotLeadingPaddingWidthChanged(qreal width);
+    void slotSidePaddingWidthChanged(qreal width);
     void slotItemHovered(int index);
     void slotItemUnhovered(int index);
     void slotItemDropEvent(int index, QGraphicsSceneDragDropEvent* event);
@@ -863,7 +863,7 @@ private:
 
     void updatePlaceholderLabel();
 
-    void tryShowNameToolTip(QEvent* event);
+    void tryShowNameToolTip(QHelpEvent* event);
 
 private:
     void updatePalette();
@@ -875,7 +875,14 @@ private:
     bool m_isFolderWritable;
     bool m_dragging; // True if a dragging is done. Required to be able to decide whether a
                      // tooltip may be shown when hovering an item.
-    bool m_loading;
+
+    enum class LoadingState {
+        Idle,
+        Loading,
+        Canceled,
+        Completed
+    };
+    LoadingState m_loadingState = LoadingState::Idle;
 
     QUrl m_url;
     QString m_viewPropertiesContext;
@@ -912,6 +919,7 @@ private:
     // For unit tests
     friend class TestBase;
     friend class DolphinDetailsViewTest;
+    friend class DolphinMainWindowTest;
     friend class DolphinPart;                   // Accesses m_model
 };
 
